package org.processmining.release;

import java.util.Collection;
import java.util.List;

import org.processmining.contexts.uitopia.UIPluginContext;
import org.processmining.contexts.uitopia.annotations.UITopiaVariant;
import org.processmining.contexts.uitopia.packagemanager.PMController;
import org.processmining.contexts.uitopia.packagemanager.PMPackage;
import org.processmining.framework.plugin.PluginDescriptor;
import org.processmining.framework.plugin.annotations.Plugin;
import org.processmining.framework.plugin.annotations.PluginVariant;
import org.processmining.framework.util.HTMLToString;

@Plugin(name = "BPM 2010 release", parameterLabels = { }, returnLabels = {
"Release info" }, returnTypes = { HTMLToString.class }, userAccessible = true)
public class BPM2010 implements HTMLToString {
	
	private Collection<PluginDescriptor> pluginDescriptors;
	
	private BPM2010(UIPluginContext context) {
		pluginDescriptors = context.getPluginManager().getAllPlugins();
	}
	
	@UITopiaVariant(affiliation = UITopiaVariant.EHV, author = "H.M.W. Verbeek", email = "h.m.w.verbeek@tue.nl")
	@PluginVariant(variantLabel = "Default", requiredParameterLabels = { })
	public static HTMLToString info(final UIPluginContext context) {
		return new BPM2010(context);
	}

	@Override
	public String toHTMLString(boolean includeHTMLTags) {
		StringBuffer buffer = new StringBuffer();
		
		if (includeHTMLTags) {
			buffer.append("<html>");
		}
		buffer.append("<h1>ProM 6.0 BPM 2010 release</h1>");
		
		PMController packageController = new PMController();
		List<? extends PMPackage> uptodatePackages = packageController.getToUninstallPackages();
		List<? extends PMPackage> outofdatePackages = packageController.getToUpdatePackages();
		buffer.append("<h2>Installed packages</h2>");
		buffer.append("<table>");
		buffer.append("<tr><th>Package</th><th>Dependency</th><th>Version</th><th>Author</th></tr>");
		for (PMPackage pack: uptodatePackages) {
			buffer.append("<tr>");
			buffer.append("<td>" + pack.getPackageName() + "</td>");
			buffer.append("<td></td>");
			buffer.append("<td>" + pack.getVersion() + "</td>");
			buffer.append("<td>" + pack.getAuthorName() + "</td>");
			buffer.append("</tr>");
			for (String s: pack.getDependencies()) {
				buffer.append("<tr><td></td><td>" + s + "</td><td></td><td></td></tr>");
			}
		}
		buffer.append("</table>");
		buffer.append("<h3>Updates available</h3>");
		buffer.append("<table>");
		buffer.append("<tr><th>Package</th><th>Dependency</th><th>Version</th><th>Author</th></tr>");
		for (PMPackage pack: outofdatePackages) {
			buffer.append("<tr>");
			buffer.append("<td>" + pack.getPackageName() + "</td>");
			buffer.append("<td></td>");
			buffer.append("<td>" + pack.getVersion() + "</td>");
			buffer.append("<td>" + pack.getAuthorName() + "</td>");
			buffer.append("</tr>");
			for (String s: pack.getDependencies()) {
				buffer.append("<tr><td></td><td>" + s + "</td><td></td><td></td></tr>");
			}
		}
		buffer.append("</table>");
		
		buffer.append("<h2>Available plug-ins</h2>");
		buffer.append("<table>");
		buffer.append("<tr><th>Plug-in</th></tr>");
		for (PluginDescriptor pluginDescriptor: pluginDescriptors) {
			buffer.append("<tr>");
			buffer.append("<td>" + pluginDescriptor.getName() + "</td>");
			buffer.append("</tr>");
		}
		buffer.append("</table>");
		if (includeHTMLTags) {
			buffer.append("</html>");
		}
		return buffer.toString();
	}
}
